'use client';

import '@/styles/globals.css';
import { cn } from '@/lib/utils';
import { AuthContextProvider, ThemeProvider } from '@/lib/hooks/context';
import { Button, Toaster } from '@/components/ui';
import * as Sentry from '@sentry/nextjs';
import NextError from 'next/error';
import { useEffect } from 'react';
import { Inter } from 'next/font/google';

const fontSans = Inter({
  subsets: ['latin'],
  variable: '--font-sans',
});

type GlobalErrorProps = {
  error: Error & { digest?: string };
  reset?: () => void;
};

const GlobalError = ({ error, reset = undefined }: GlobalErrorProps) => {
  useEffect(() => { Sentry.captureException(error) }, [error]);
  return (
   <html
      lang='en'
      className={cn('font-sans antialiased', fontSans.variable)}
      suppressHydrationWarning
    >
      <body>
        <ThemeProvider
          attribute='class'
          defaultTheme='system'
          enableSystem
          disableTransitionOnChange
        >
          <AuthContextProvider>
            <main className='min-h-screen flex flex-col items-center'>
              <NextError statusCode={0} />
              {reset !== undefined && (
                <Button onClick={() => reset()}>Try Again</Button>
              )}
              <Toaster />
            </main>
          </AuthContextProvider>
        </ThemeProvider>
      </body>
    </html>
  );
};
export default GlobalError;
