'use client';
import { SubmitButton, type SubmitButtonProps } from '@/components/default/forms';
import { useRouter } from 'next/navigation';
import { useAuth } from '@/lib/hooks/context';
import { signOut } from '@/lib/queries';
import { useSupabaseClient } from '@/utils/supabase';
import { cn } from '@/lib/utils';

type SignOutProps = Omit<SubmitButtonProps, 'disabled' | 'onClick'>

export const SignOut = ({
  className,
  pendingText = 'Signing out...',
  ...props
}: SignOutProps) => {

  const supabase = useSupabaseClient();
  const { loading, refreshUser } = useAuth();
  const router = useRouter();

  const handleSignOut = async () => {
    try {
      if (!supabase) throw new Error('Supabase client not found');
      const result = await signOut(supabase);
      if (result.error) throw new Error(result.error.message);
      await refreshUser();
      router.push('/sign-in');
    } catch (error) {
      console.error(error);
    }
  };

  return (
    <SubmitButton
      disabled={loading}
      onClick={handleSignOut}
      {...props}
      pendingText={pendingText}
      className={cn(
        'text-[1.0rem] font-semibold \
        hover:bg-red-700/60 dark:hover:bg-red-300/80',
        className
      )}
    >
      Sign Out
    </SubmitButton>
  );
};
