'use server';
import { signInWithMicrosoft } from '@/lib/queries';
import {
  SubmitButton,
  type SubmitButtonProps,
} from '@/components/default/forms';
import { SupabaseServer } from '@/utils/supabase';
import { FaMicrosoft } from 'react-icons/fa';
import { type ComponentProps } from 'react';
import { cn } from '@/lib/utils';

export type SignInWithMicrosoftProps = {
  submitButtonProps?: SubmitButtonProps;
  formProps?: ComponentProps<'form'>;
  textProps?: ComponentProps<'p'>;
  iconProps?: ComponentProps<'svg'>;
};

export const SignInWithMicrosoft = async ({
  submitButtonProps,
  formProps,
  textProps,
  iconProps,
} : SignInWithMicrosoftProps) => {
  const supabase = await SupabaseServer();

  const handleSignInWithMicrosoft = async () => {
    try {
      if (!supabase) throw new Error('Supabase client not found');
      const result = await signInWithMicrosoft(supabase);
      if (result.error)
        throw new Error(`Error signing in with Microsoft: ${result.error.message}`);
      else if (result.data.url) window.location.href = result.data.url;
    } catch (error) {
      console.error(error);
    }
  };

  return (
    <form
      action={handleSignInWithMicrosoft}
      {...formProps}
      className={cn('my-4', formProps?.className)}
    >
      <SubmitButton
        pendingText='Signing in...'
        {...submitButtonProps}
        className={cn('w-full', submitButtonProps?.className)}
      >
        <div className='flex items-center gap-2'>
          <FaMicrosoft {...iconProps} className={cn('size-5', iconProps?.className)} />
          <p {...textProps} className={cn('text-[1.0rem]', textProps?.className)}>
            Sign In with Microsoft
          </p>
        </div>
      </SubmitButton>
    </form>
  );
};
